@@ -2,16 +2,11 @@
 # import questions
 import pygame
 import pygame.gfxdraw
-import textwrap
-import os
-import sys
 # from player import Player, Coffee, Ruby, Eye
 import random
 from openpyxl import load_workbook, Workbook
 from pygame.locals import *
 
-print(os.listdir("path"))
-
 class Screen():
     def __init__(self, width, height):
         self.width = width
@@ -26,6 +21,7 @@ class damage():
         self.userDamage = newUserDam
         self.enemyDamage = newEnemyDam
 
+#-----from player.py-----#
 class Player(pygame.sprite.Sprite):
     def __init__(self):
         pygame.sprite.Sprite.__init__(self)
@@ -154,13 +150,13 @@ class Eye(pygame.sprite.Sprite):
         self.y = y
         self.rect = pygame.Rect(x, y, self.width, self.height)
 
+#-----from questions.py-----#
 def initialize(filename):
     wk = load_workbook(filename=filename)
 
     ws = wk.active
     return ws
 
-
 def load_question(category):
     print("Question Categories: ")
     print("1 Syntax\n2 Vocabulary\n3 Logic\n4 Number Conversion\n5 General\n")
@@ -180,19 +176,6 @@ def load_question(category):
     print(value)
     return value
 
-
-'''
-def get_question(value):
-    question = ws['B' + str(value)].value
-    #print(ws[question].value)
-    choices = ws['D' + str(value)].value
-    #print(ws[choices].value)
-    answer = ws['E' + str(value)].value
-
-    return question, choices, answer 
-'''
-
-
 def get_result(guess, answer):
     if guess == answer or guess == answer.capitalize() or guess == answer + '.' or guess == answer.capitalize() + '.':
         # print("Correct!")
@@ -201,7 +184,6 @@ def get_result(guess, answer):
         # print("Incorrect")
         return False
 
-
 def get_question(value,ws):
     # list returned has the info
     # 0 has the question
@@ -231,14 +213,13 @@ def get_question(value,ws):
 
     return the_question
 
-
 def changeQuestionDeck(filename, ws):
     wk = load_workbook(filename=filename)
     ws = wk.active
     print("Loaded")
     return ws
 
-
+#-----from Button.py-----#
 class button():
     def __init__(self, color, x, y, width, height, text=''):
         self.color = color
@@ -280,7 +261,6 @@ class button():
 
         return False
 
-
 class text():
     def __init__(self, color, x, y, width, height, textSize, text):
         self.color = color
@@ -316,7 +296,6 @@ class text():
                     screen.blit(text, (round(self.x + self.width), round(self.y + i)))
                     i += 37
 
-
 class healthBar():
     def __init__(self, x, y, width, height, health, orientation):
         self.x = x
@@ -356,13 +335,12 @@ class healthBar():
             # screen.blit(text, text_rect)
         pygame.display.update()
 
-
 # class level():
 #     def __init__(self, level):
 #         self.level = level
 
-
-ws = initialize("./python_questions.xlsx")
+#-----initialize objects etc-----#
+ws = initialize("python_questions.xlsx")
 screen = pygame.display.set_mode((0, 0), pygame.RESIZABLE)
 white = (255, 255, 255)
 purple = (110, 113, 198)
@@ -379,15 +357,12 @@ height = screen.get_height()
 #screen.fill(lime)
 
 clock = pygame.time.Clock()
-
 theScreen = Screen(screen.get_width(), screen.get_height())
 
 userHealth = healthBar(20, 20, 200, 30, 100, "left")
 enemyHealth = healthBar(width - 20 - 200, 20, 200, 30, 100, "right")
 damageStats = damage(50, 10)
 
-
-
 cat1 = button(fuschia, 400, 200, 30, 30, " " + ws['C2'].value)
 cat2 = button(fuschia, 650, 200, 30, 30, " " + ws['C7'].value)
 cat3 = button(fuschia, 900, 200, 30, 30, " " + ws['C12'].value)
@@ -439,10 +414,24 @@ changeHistory = button(color_light, (width * 0.25), (height * 8 / 14), (width *
 #options -> change sound settings
 sound_header = text(black, (width * 0.25), (height * 0 / 12), (width * 0.5), (height * 2 / 10), 150,
                                ["SOUND SETTINGS"])
+mute_button = button(color_light, (width * 0.25), (height * 3 / 12), (width * 0.5), (height * 2 / 10),
+                                      "Mute")
+unmute_button = button(color_light, (width * 0.25), (height * 3 / 12), (width * 0.5), (height * 2 / 10),
+                                      "Unmute")
+volume_label = text(black,(width * 0.25), (height * 6 / 12), (width * 0.5), (height * 2 / 10), 100,
+                               ["Volume"])
+#volume_minus
+#volume_plus
 
 
 def resize(startWidth, startHeight):
-    # category/answer buttons
+    #screen
+    theScreen.width = startWidth
+    theScreen.height = startHeight
+    chooseCat.modify((theScreen.width * 0.25), (theScreen.height * 0 / 12), (theScreen.width * 0.5),
+                     (theScreen.height * 1 / 10))
+
+    #battle category/answer buttons
     cat1.modify(0.25 * startWidth, 0.22 * startHeight, startWidth * 0.025, startHeight * 0.025)
     cat2.modify(0.41 * startWidth, 0.22 * startHeight, startWidth * 0.025, startHeight * 0.025)
     cat3.modify(0.56 * startWidth, 0.22 * startHeight, startWidth * 0.025, startHeight * 0.025)
@@ -472,11 +461,9 @@ def resize(startWidth, startHeight):
 
     #options -> change sound settings menu
     sound_header.modify((startWidth * 0.25), (startHeight * 0 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
-
-    theScreen.width = startWidth
-    theScreen.height = startHeight
-    chooseCat.modify((theScreen.width * 0.25), (theScreen.height * 0 / 12), (theScreen.width * 0.5),
-                     (theScreen.height * 1 / 10))
+    mute_button.modify((startWidth * 0.25), (startHeight * 3 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
+    unmute_button.modify((startWidth * 0.25), (startHeight * 3 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
+    volume_label.modify((startWidth * 0.25), (startHeight * 6 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
 
 def reDrawStartWindow():
     screen.fill(gold)
@@ -486,6 +473,7 @@ def reDrawStartWindow():
     quitButton.draw(screen, int(theScreen.width*0.05), black, True)
 
 def startscreen():
+    resize(theScreen.width, theScreen.height)
     reDrawStartWindow()
     while True:
         # reDrawStartWindow()
@@ -495,21 +483,7 @@ def startscreen():
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
-            if ev.type == pygame.VIDEORESIZE:
 
-                # if (ev.w != theScreen.width):
-                #     theScreen.width = ev.w
-                #     theScreen.height = int(theScreen.width * 900 / 1600)
-                # else:
-                #     theScreen.height = ev.h
-                #     theScreen.width = int(theScreen.height * 1600 / 900)
-
-                theScreen.width = ev.w
-                theScreen.height = ev.h
-
-                pygame.display.set_mode((theScreen.width, theScreen.height), pygame.RESIZABLE)
-                resize(theScreen.width, theScreen.height)
-                reDrawStartWindow()
             if ev.type == pygame.MOUSEBUTTONDOWN:
                 if startButton.isOver(pos):
                     # print("clicked start button")
@@ -521,12 +495,23 @@ def startscreen():
                     # print("clicked quit button")
                     return "quit"
 
+            if ev.type == pygame.VIDEORESIZE:
+                if (ev.w != theScreen.width):
+                    theScreen.width = ev.w
+                    theScreen.height = int(theScreen.width * 900 / 1600)
+                else:
+                    theScreen.height = ev.h
+                    theScreen.width = int(theScreen.height * 1600 / 900)
+
+                pygame.display.set_mode((theScreen.width, theScreen.height), pygame.RESIZABLE)
+                resize(theScreen.width, theScreen.height)
+                reDrawStartWindow()
+
         pygame.display.update()
 
 def drawCategories(color, text_color):
-    chooseCat = text(color, (theScreen.width * 0.25), (theScreen.height * 0.5 / 12), (theScreen.width * 0.5),
-                            (theScreen.height * 1 / 10),
-                            100, ["Choose a category:"])
+    chooseCat = text(color, (theScreen.width * 0.25), (theScreen.height * 0.5 / 12), (theScreen.width * 0.5), (theScreen.height * 1 / 10), 100,
+                     ["Choose a category:"])
     cat1 = button(color, theScreen.width * 0.25, theScreen.height * 0.22, theScreen.width * 0.025, theScreen.height * 0.025, " " + ws['C2'].value)
     cat2 = button(color, theScreen.width * 0.41, theScreen.height * 0.22, theScreen.width * 0.025, theScreen.height * 0.025, " " + ws['C7'].value)
     cat3 = button(color, theScreen.width * 0.56, theScreen.height * 0.22, theScreen.width * 0.025, theScreen.height * 0.025, " " + ws['C12'].value)
@@ -548,6 +533,7 @@ def chooseCategory(playerGroup, enemyGroup,level,color,text_color):
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
+
             if ev.type == pygame.MOUSEBUTTONDOWN:
                 if cat1.isOver(pos):
                     print(1)
@@ -566,9 +552,12 @@ def chooseCategory(playerGroup, enemyGroup,level,color,text_color):
                     return 5
 
             if ev.type == pygame.VIDEORESIZE:
-
-                theScreen.width = ev.w
-                theScreen.height = ev.h
+                if (ev.w != theScreen.width):
+                    theScreen.width = ev.w
+                    theScreen.height = int(theScreen.width * 900 / 1600)
+                else:
+                    theScreen.height = ev.h
+                    theScreen.width = int(theScreen.height * 1600 / 900)
 
                 pygame.display.set_mode((theScreen.width, theScreen.height), pygame.RESIZABLE)
                 resizeBattle(theScreen.width, theScreen.height)
@@ -589,7 +578,7 @@ def resizeBattle(startWidth, startHeight):
     cat1.modify(0.25 * startWidth, 0.22 * startHeight, startWidth * 0.025, startHeight * 0.025)
     cat2.modify(0.41 * startWidth, 0.22 * startHeight, startWidth * 0.025, startHeight * 0.025)
     cat3.modify(0.56 * startWidth, 0.22 * startHeight, startWidth * 0.025, startHeight * 0.025)
-    cat4.modify(0.28 * startWidth, 0.4 * startHeight, startWidth * 0.025, startHeight * 0.025)
+    cat4.modify(0.25 * startWidth, 0.4 * startHeight, startWidth * 0.025, startHeight * 0.025)
     cat5.modify(0.5 * startWidth, 0.4 * startHeight, startWidth * 0.025, startHeight * 0.025)
 
     pygame.display.update()
@@ -608,6 +597,7 @@ def chooseAnswer(playerGroup, enemyGroup, question ,level,q,A,B,C,D, text_color)
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
+
             if ev.type == pygame.MOUSEBUTTONDOWN:
                 if a.isOver(pos):
                     return 'a'
@@ -617,19 +607,25 @@ def chooseAnswer(playerGroup, enemyGroup, question ,level,q,A,B,C,D, text_color)
                     return 'c'
                 elif d.isOver(pos):
                     return 'd'
-            if ev.type == pygame.VIDEORESIZE:
 
-                theScreen.width = ev.w
-                theScreen.height = ev.h
+            if ev.type == pygame.VIDEORESIZE:
+                if (ev.w != theScreen.width):
+                    theScreen.width = ev.w
+                    theScreen.height = int(theScreen.width * 900 / 1600)
+                else:
+                    theScreen.height = ev.h
+                    theScreen.width = int(theScreen.height * 1600 / 900)
 
                 pygame.display.set_mode((theScreen.width, theScreen.height), pygame.RESIZABLE)
                 resizeBattle(theScreen.width, theScreen.height)
                 drawBattle(playerGroup, enemyGroup, theScreen.width, theScreen.height,level)
+
                 q.modify(theScreen.width * 0.25, theScreen.height * 1/9, 50, 50)
                 A.modify(a.x, a.y, 50, 50)
                 B.modify(b.x, b.y, 50, 50)
                 C.modify(c.x, c.y, 50, 50)
                 D.modify(d.x, d.y, 50, 50)
+
                 q.draw(screen, int(theScreen.width * 0.02), False)
                 A.draw(screen, int(theScreen.width * 0.015), False)
                 B.draw(screen, int(theScreen.width * 0.015), False)
@@ -670,12 +666,12 @@ def drawBackground(playerGroup, enemyGroup, width, height, level, correctOrWrong
     screen.blit(bg,(0,0))
     if correctOrWrong != "":
         if correctOrWrong == "Correct":
-            pygame.mixer.Sound("correct.wav").play()
+            #pygame.mixer.Sound("correct.wav").play(0)
             display = text(black, theScreen.width * 0.25, theScreen.height * 0.2, theScreen.width * 0.5,
                                   theScreen.height * 0.4, int(theScreen.width * 0.02), ["Correct"])
             pygame.draw.rect(screen, (0,255,0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
         if correctOrWrong == "Wrong":
-            pygame.mixer.Sound("incorrect.wav").play()
+            #pygame.mixer.Sound("incorrect.wav").play(0)
             display = text(black, theScreen.width * 0.25, theScreen.height * 0.2, theScreen.width * 0.5,
                                   theScreen.height * 0.4, int(theScreen.width * 0.02), ["Incorrect"])
             pygame.draw.rect(screen, (255, 0, 0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
@@ -834,14 +830,13 @@ def animationController(playerGroup, enemyGroup, width, height, clock, level, an
         enemyGroup.draw(screen)
         pygame.display.update()
 
-def theBattle(level):
+def theBattle(level, sounds=True):
     health = 100
     enemy_health = 100
     userHealth.set_health(health)
     enemyHealth.set_health(enemy_health)
 
     resizeBattle(theScreen.width, theScreen.height)
-
     clock = pygame.time.Clock()
 
     myPlayer = Player()
@@ -851,31 +846,32 @@ def theBattle(level):
     cat_button_color = white
     ans_button_color = white
     text_color = white
-    if level == 1:
-        text_color = black
-        cat_button_color = fuschia
-        ans_button_color = color_light
 
+    if level == 1:
         myEnemy = Coffee()
-        pygame.mixer.music.load('jazz.mp3')
-        pygame.mixer.music.play(-1)
+        if sounds:
+            pygame.mixer.music.load('jazz.mp3')
+            pygame.mixer.music.play(-1)
+        text_color = (108, 16, 40)
+        cat_button_color = (171, 92, 187)
+        ans_button_color = color_light
     elif level == 2:
+        myEnemy = Ruby()
+        if sounds:
+            pygame.mixer.music.load('funke.mp3')
+            pygame.mixer.music.play(-1)
         cat_button_color = (240,208,79)
         text_color = color_light
         ans_button_color = color_dark
-
-        myEnemy = Ruby()
-        pygame.mixer.music.load('funke.mp3')
-        pygame.mixer.music.play(-1)
     else:
+        myEnemy = Eye()
+        if sounds:
+            pygame.mixer.music.load('bluth.wav')
+            pygame.mixer.music.play(-1)
         cat_button_color = color_dark
         text_color = color_light
         ans_button_color = color_dark
 
-        myEnemy = Eye()
-        pygame.mixer.music.load('bluth.wav')
-        pygame.mixer.music.play(-1)
-
     enemyGroup = pygame.sprite.Group(myEnemy)
     # enemyGroup.draw(screen)
     pygame.display.update()
@@ -928,8 +924,6 @@ def theBattle(level):
                 animationController(playerGroup, enemyGroup, theScreen.width, theScreen.height, clock,level, "ruby hurt")
             else:
                 animationController(playerGroup, enemyGroup, theScreen.width, theScreen.height, clock, level, "eye hurt")
-
-
         else:
             health = health - damageStats.enemyDamage
             userHealth.set_health(health)
@@ -943,7 +937,6 @@ def theBattle(level):
             else:
                 animationController(playerGroup, enemyGroup, theScreen.width, theScreen.height, clock, level, "eye attack")
             animationController(playerGroup, enemyGroup, theScreen.width, theScreen.height, clock,level, "snake hurt")
-            
 
         if health <= 0:
             battle = False
@@ -953,12 +946,12 @@ def theBattle(level):
             battle = False
             if level == 1:
                 animationController(playerGroup, enemyGroup, theScreen.width, theScreen.height, clock,level, "coffee break")
-
             return "win"
 
-def win():
-    pygame.mixer.music.load('victoire.mp3')
-    pygame.mixer.music.play(-1)
+def win(sounds=True):
+    if sounds:
+        pygame.mixer.music.load('victoire.mp3')
+        pygame.mixer.music.play(-1)
 
     print("You won!")
     screen.fill((100, 100, 100))
@@ -974,9 +967,10 @@ def win():
     pygame.display.update()
     pygame.time.delay(4000)
 
-def lose():
-    pygame.mixer.music.load('defaite.mp3')
-    pygame.mixer.music.play(-1)
+def lose(sounds=True):
+    if sounds:
+        pygame.mixer.music.load('defaite.mp3')
+        pygame.mixer.music.play(-1)
 
     print("You lost!")
     screen.fill((100, 100, 100))
@@ -1006,20 +1000,22 @@ def options():
     while opt:
         for ev in pygame.event.get():
             pos = pygame.mouse.get_pos()
+
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
+
             if ev.type == pygame.MOUSEBUTTONDOWN:
                 if back_to_main.isOver(pos):
                     opt = False
                 if choose_q_deck.isOver(pos):
                     q_deck_menu()
                     opt = False
-                    break
                 if change_sound_settings.isOver(pos):
-                    sound_settings_menu()
+                    #sound_settings_menu()
+                    return sound_settings_menu()
                     opt = False
-                    break
+
             if ev.type == pygame.VIDEORESIZE:
                 if (ev.w != theScreen.width):
                     theScreen.width = ev.w
@@ -1027,7 +1023,6 @@ def options():
                 else:
                     theScreen.height = ev.h
                     theScreen.width = int(theScreen.height * 1600 / 900)
-
                 pygame.display.set_mode((theScreen.width, theScreen.height), pygame.RESIZABLE)
                 resize(theScreen.width, theScreen.height)
                 reDrawOptionsWindow()
@@ -1048,9 +1043,11 @@ def q_deck_menu():
     while opt:
         for ev in pygame.event.get():
             pos = pygame.mouse.get_pos()
+
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
+
             if ev.type == pygame.MOUSEBUTTONDOWN:
                 if back_to_options.isOver(pos):
                     options()
@@ -1067,6 +1064,7 @@ def q_deck_menu():
                     globals()['ws'] = changeQuestionDeck("python_questions_timeline.xlsx", ws)
                     options()
                     opt = False
+
             if ev.type == pygame.VIDEORESIZE:
                 if (ev.w != theScreen.width):
                     theScreen.width = ev.w
@@ -1080,9 +1078,14 @@ def q_deck_menu():
                 redraw_q_deck_window()
 
 #options -> change sound settings
-def redraw_sound_window():
+def redraw_sound_window(sounds=True):
     screen.fill(blue)
     sound_header.draw(screen, int(theScreen.width*0.1), True)
+    if sounds:
+        mute_button.draw(screen, int(theScreen.width*0.06), black, True)
+    else:
+        unmute_button.draw(screen, int(theScreen.width*0.06), black, True)
+    volume_label.draw(screen, int(theScreen.width*0.06), True)
     back_to_options.draw(screen, int(theScreen.width*0.04), black, True)
     pygame.display.update()
 
@@ -1099,6 +1102,14 @@ def sound_settings_menu():
                 if back_to_options.isOver(pos):
                     options()
                     opt = False
+                if mute_button.isOver(pos):
+                    pygame.mixer.music.pause()
+                    redraw_sound_window(False)
+                    return False
+                if unmute_button.isOver(pos):
+                    pygame.mixer.music.pause()
+                    redraw_sound_window(True)
+                    return True
             if ev.type == pygame.VIDEORESIZE:
                 if (ev.w != theScreen.width):
                     theScreen.width = ev.w
@@ -1134,15 +1145,14 @@ def levelChange(screen, level, Enemy, enemyImg):
     pygame.time.delay(2000)
 
 def main():
-
     pygame.init()
-
     pygame.display.set_caption("Python Pals")
 
     enter_game = True
     restart_music = True
+    sound = True
     while enter_game:
-        if(restart_music == True):
+        if(sound and restart_music):
             pygame.mixer.music.load('idle.wav')
             pygame.mixer.music.play(-1)
 
@@ -1153,30 +1163,32 @@ def main():
         if menuOption == "start":
             damageStats.modify(50,10)
             levelChange(screen, 1, "Java", "coffee1.png")
-            result = theBattle(1)
+            result = theBattle(1, sound)
             restart_music = True
             if result == "win":
                 levelChange(screen, 2, "Ruby", "Ruby_idle.png")
                 damageStats.modify(25,25)
-                result2 = theBattle(2)
+                result2 = theBattle(2, sound)
                 if result2 == "win":
                     levelChange(screen, 3, "Eye", "C1.png")
                     damageStats.modify(17,25)
-                    result3 = theBattle(3)
+                    result3 = theBattle(3, sound)
                     if result3 == "win":
-                        win()
+                        win(sound)
                     else:
-                        lose()
+                        lose(sound)
                 else:
-                    lose()
+                    lose(sound)
             else:
-                lose()
+                lose(sound)
         elif menuOption == "options":
-            options()
             restart_music = False
+            if not options():
+                sound = False
+                #pygame.mixer.music.pause()
         elif menuOption == "quit":
             enter_game = False
-            restart_music = False
+            #restart_music = False
     # pygame.mixer.music.stop()
     pygame.quit()
 
